@@ -226,7 +226,7 @@ sub SplitterWindow {
                                  wxBITMAP_TYPE_JPEG );
    my $underway  = Wx::Bitmap->new("underway.jpg",
                                  wxBITMAP_TYPE_JPEG );
-   my $demodone  = Wx::Bitmap->new("demodone.jpg",
+   my $taskdone  = Wx::Bitmap->new("taskdone.jpg",
                                  wxBITMAP_TYPE_JPEG );
    my $steel = Wx::Bitmap->new(
          "Scratched_Steel_Texture_by_AaronDesign_Enlarged.jpg",
@@ -248,7 +248,7 @@ sub SplitterWindow {
    $rightbottom->{notready}=$notready;
    $rightbottom->{presshere}=$presshere;
    $rightbottom->{underway}=$underway;
-   $rightbottom->{demodone}=$demodone;
+   $rightbottom->{taskdone}=$taskdone;
    $rightbottom->{righttop}=$righttop;
    $rightbottom->DragAcceptFiles(1);
    $rightbottom->SetBackgroundColour(Wx::Colour->new(128,128,128));
@@ -388,6 +388,7 @@ sub SplitterWindow {
    }
 
    my $new_server_chkbox='';
+   my $export_logs_chkbox='';
    my $export_putty_chkbox='';
    my $chk=169;
    $chk=99 if !exists $rightbottom->{firstpaint}
@@ -398,12 +399,24 @@ sub SplitterWindow {
    $rightbottom->{epcb}=$export_putty_chkbox;
    EVT_CHECKBOX( $rightbottom, $export_putty_chkbox,
                            \&main::OnClick_chkbox2 );
-   $new_server_chkbox=Wx::CheckBox->new($rightbottom,-1,'',[440,$chk],
+   #$new_server_chkbox=Wx::CheckBox->new($rightbottom,-1,'',[440,$chk],
+   #                       [-1,-1],wxTRANSPARENT_WINDOW);
+   #$new_server_chkbox->SetBackgroundColour(Wx::Colour->new(77,77,77));
+   #$rightbottom->{nscb}=$new_server_chkbox;
+   #$new_server_chkbox->SetValue(1) unless ($ip_txt || $saved_txt);
+   $export_logs_chkbox=Wx::CheckBox->new($rightbottom,-1,'',[440,$chk],
                           [-1,-1],wxTRANSPARENT_WINDOW);
-   $new_server_chkbox->SetBackgroundColour(Wx::Colour->new(77,77,77));
-   $rightbottom->{nscb}=$new_server_chkbox;
-   $new_server_chkbox->SetValue(1) unless ($ip_txt || $saved_txt);
-   EVT_CHECKBOX( $rightbottom, $new_server_chkbox,
+   $export_logs_chkbox->SetBackgroundColour(Wx::Colour->new(77,77,77));
+   if (($pem_file && $ip_txt) || $saved_txt) {
+      $export_logs_chkbox->Enable(1);
+   } else {
+      $export_logs_chkbox->Enable(0);
+   }
+   $rightbottom->{elcb}=$export_logs_chkbox;
+   
+   #EVT_CHECKBOX( $rightbottom, $new_server_chkbox,
+   #                        \&main::OnClick_chkbox3 );
+   EVT_CHECKBOX( $rightbottom, $export_logs_chkbox,
                            \&main::OnClick_chkbox3 );
    #my $eng = Wx::Bitmap->new("engineroom.jpg",
    #                      wxBITMAP_TYPE_JPEG );
@@ -492,7 +505,7 @@ sub on_paint {
     }
     $self->{firstpaint}=$firstpaint;
     $dc->SetTextForeground(Wx::Colour->newRGB(192,192,192));
-    $dc->DrawText('Launch New FullAuto Server',460,$chk);
+    $dc->DrawText('Export FullAuto Log Files',460,$chk);
     $dc->DrawText('Export PuTTY',244,$chk-87); # 139 $chk-83
 
 }
@@ -514,6 +527,17 @@ sub evt_process_exit {
        @lines=<FH>;
        close FH;
        $log_out=join '',@lines;
+       my $fa_log=$log_out;
+       $fa_log=~s/^.*?LOGFILE ==[>] ["](.*?)["].*$/$1/s;
+       my $falog=$fa_log;
+       $falog=~s/^.*\/(.*)$/$1/s;
+       my $c="pscp.exe -batch -v -i \"$self->{ppk_file}\" ".
+             "ec2-user\@$self->{ip_txt}:$fa_log $falog";
+       Wx::Shell($c);
+       system("copy putty.log output.txt");
+       sleep 1;
+       system("zip.exe logs.zip $falog");
+       system("zip.exe logs.zip output.txt");
     }
     my $webapp_url='';
     my $set_shifted_flag=0;
@@ -529,7 +553,7 @@ sub evt_process_exit {
       $self->{shifted_cmds}=$proc;
       $proc->Run;
     } elsif (!exists $self->{webapp}) {
-      my $hadoop_flag=0;my $count=0;
+      my $count=0;
       foreach my $line (reverse @lines) {
          $count++;
          if ($line=~/GNU.io/ or $line=~/clipbucket[.]com/i) {
@@ -547,30 +571,29 @@ sub evt_process_exit {
       }
     }
     if (!(exists $self->{webapp}) && $webapp_url) {
-      #$self->{donetime}=time()+3600 unless exists $self->{donetime};
       $self->{dashboard}->SetBackgroundColour(Wx::Colour->new(32,161,35));
-      $self->{statbm}->SetBitmap($self->{demodone});
+      $self->{statbm}->SetBitmap($self->{taskdone});
       $webapp_flag=1;
       $self->{webapp}=1;
       Wx::LaunchDefaultBrowser($webapp_url,wxBROWSER_NEW_WINDOW);
       $self->{bb}->Enable(1);
+      $self->{elcb}->Enable(1);
       $self->{cleanup}->Enable(1);
       $self->{fp3}->Enable(1);
     } 
     if ((!(exists $self->{shifted_cmds}) && !(exists $self->{webapp})) ||
-         (!($set_shifted_flag) && !($webapp_flag))) {
-      #if (!$self->{donetime} || $self->{donetime}<time()) {
-         $self->{dashboard}->SetBackgroundColour(Wx::Colour->new(32,161,35));
-         $self->{statbm}->SetBitmap($self->{presshere});
-         $self->{statbm}->SetToolTip(
-            Wx::ToolTip->new( Wx::gettext('Press FA =>') ) );
-         $self->{bb}->Enable(1);
-         $self->{fp3}->Enable(1);
-         $self->{cleanup}->Enable(1);
-         $self->{key}->Enable(1);
-         $self->{credentials}->Enable(1);
-         $self->{ipbox}->Enable(1) unless -e "putty.log";
-      #}
+          (!($set_shifted_flag) && !($webapp_flag))) {
+       $self->{dashboard}->SetBackgroundColour(Wx::Colour->new(32,161,35));
+       $self->{statbm}->SetBitmap($self->{presshere});
+       $self->{statbm}->SetToolTip(
+          Wx::ToolTip->new( Wx::gettext('Press FA =>') ) );
+       $self->{bb}->Enable(1);
+       $self->{elcb}->Enable(1);
+       $self->{fp3}->Enable(1);
+       $self->{cleanup}->Enable(1);
+       $self->{key}->Enable(1);
+       $self->{credentials}->Enable(1);
+       $self->{ipbox}->Enable(1) unless -e "putty.log";
     }
 
 }
@@ -589,7 +612,8 @@ sub fullauto_button {
    $self->{fp3}->Enable(0);
    $self->{dashboard}->SetBackgroundColour(Wx::Colour->new(248,115,17));
    $self->{statbm}->SetBitmap($self->{underway});
-   $self->{nscb}->SetValue(0);
+   #$self->{nscb}->SetValue(0);
+   $self->{elcb}->Enable(0);
    $self->{bb}->Enable(0);
    $self->{cleanup}->Enable(0);
    my $title='IMPORTANT!';
@@ -776,6 +800,7 @@ sub on_change {
       $self->{dashboard}->SetBackgroundColour(Wx::Colour->new(32,161,35));
       $self->{bb}->SetBitmap($self->{bmp});
       $self->{bb}->Enable(1);
+      $self->{elcb}->Enable(1);
       $self->{fp3}->Enable(1);
       $self->{cleanup}->Enable(1);
    } elsif ($text=$self->{fp1}->GetPath()) {
@@ -874,6 +899,35 @@ sub OnClick_chkbox2 {
 
 sub OnClick_chkbox3 {
 
+   my ($self, $event) =@_;
+   my $desktop=$ENV{HOMEDRIVE}.$ENV{HOMEPATH}.'\\desktop';
+   my $filedlg = Wx::FileDialog->new($self,         # parent
+                                     'Open File',   # Caption
+                                     $desktop,      # Default directory
+                                     'logs',        # Default file
+                                     "FullAuto Log Files (*.zip)|*.zip",
+                                                    # wildcard
+                                     wxFD_SAVE|wxFD_OVERWRITE_PROMPT); #style
+   # If the user really selected one
+   unless (-e "logs.zip") {
+      my $title="No Log Files Available";
+      my $message="No Log Files Available - Logs are available ".
+                  "after an Instruction Set is run => $desktop";
+      my $dialog=Wx::MessageDialog->new(
+         $self,$message,$title,wxOK|wxICON_EXCLAMATION);
+      my $choice=$dialog->ShowModal();
+   } elsif ($filedlg->ShowModal==wxID_OK) {
+       my $filename = $filedlg->GetPath;
+       my $dir=$filename;
+       $dir=~s/^(.*)\\.*$/$1/;
+       copy "logs.zip", "$dir\\logs.zip";
+   }
+   $self->{elcb}->SetValue(0);
+
+}
+
+sub OnClick_chkbox_export {
+
    my ($self, $event) =@_;
    my $title='Launch New FullAuto Server?';
    my $message='';
@@ -915,7 +969,7 @@ sub OnClick_chkbox3 {
                'settings will be permanently discarded and unrecoverable '.
                "(except by manual re-entry.)\n\nDo you still wish to proceed?";
    } else {
-      $self->{nscb}->SetValue(1);
+      #$self->{nscb}->SetValue(1);
       $message='There are no saved settings, and a session is not currently '.
                'running. To run any FullAuto Instruction Set, a fully functioning '.
                'FullAuto Server is necessary, which it is the job of this '.
@@ -929,10 +983,11 @@ sub OnClick_chkbox3 {
    }
    my $dialog=Wx::MessageDialog->new(
       $self,$message,$title,wxYES|wxNO|wxICON_EXCLAMATION);
-   my $choice=$dialog->ShowModal() if $self->{nscb}->IsChecked();
+   #my $choice=$dialog->ShowModal() if $self->{nscb}->IsChecked();
+   my $choice=$dialog->ShowModal();
    $choice||=0;
    if ($choice==5104) {
-      $self->{nscb}->SetValue(0);
+      #$self->{nscb}->SetValue(0);
    } elsif (-e "saved.txt") {
       unlink "saved.txt";
       unlink "putty.log";
@@ -946,7 +1001,8 @@ sub OnClick_chkbox3 {
       $self->{fp2}->Enable(1);
       $self->{dashboard}->SetBackgroundColour(Wx::Colour->new("RED"));
       $self->{statbm}->SetBitmap($self->{notready});
-      $self->{nscb}->SetValue(1);
+      #$self->{nscb}->SetValue(1);
+      $self->{elcb}->Enable(0);
       $self->{bb}->Enable(0);
    }
 }
@@ -1324,6 +1380,7 @@ sub cleanup {
    unlink "saved.txt";
    copy "putty.log", "putty.log.bak";
    unlink "putty.log";
+   $frame->Destroy() unless $ENV{PAR_TEMP};
 
 }
 
